@@ -140,13 +140,11 @@ def read_function_url(function_name):
     return url.rstrip()
 
 
-def call_function(function_name, data):
+def call_url(url, data):
     """
-    Call a function deployed in Google Cloud Run
+    Call a web service deployed in Google Cloud Run
     """
     logging.debug(f"{data=}")
-    url = read_function_url(function_name)
-    url+=f"/{service_name}"
     logging.debug(f"Post to {url}")
     response = requests.post(url, json={'data': json.dumps(data)})
     logging.debug(f"Status: {response.status_code}")
@@ -154,6 +152,15 @@ def call_function(function_name, data):
         return response.json()
 
 
+def call_function(function_name, data):
+    """
+    Call a function deployed in Google Cloud Run
+    """
+    logging.debug(f"{data=}")
+    url = read_function_url(function_name) + "/"
+    call_url(url, data)
+
+
 def test_function(function_name, data):
     """
     Call a function with data and verify that the response's 
